@@ -107,12 +107,12 @@ public:
     bool parseDevice();
     void deleteDevice();
 
-    QDataStream  stream_;
-    QIODevice    *device_;
-    bool         deleteDevice_;
     QString      defaultdir_;
-    KTNEFAttach  *current_;
-    KTNEFMessage *message_;
+    QDataStream  stream_;
+    QIODevice    *device_ = nullptr;
+    KTNEFAttach  *current_ = nullptr;
+    KTNEFMessage *message_ = nullptr;
+    bool         deleteDevice_ = false;
 };
 //@endcond
 
